@@ -21,26 +21,15 @@ use Plack::Runner;
 
 use Net::Domain qw/hostfqdn/;
 
-our $VERSION = '0.000036';
+our $VERSION = '0.000037';
 
 use parent 'Test2::Harness::Renderer::UIDB';
 use Test2::Harness::Util::HashBase qw{
     qdb
     app
-    links
     port
 };
 
-#qw{
-#    <run
-#    <processor
-#    <config
-#    <dbh
-#    <project
-#    <user
-#    <finished
-#};
-
 sub init {
     my $self = shift;
 
@@ -49,6 +38,9 @@ sub init {
     my $schema = $settings->yathui->schema // 'PostgreSQL';
     require(pkg_to_file("Test2::Harness::UI::Schema::$schema"));
 
+    my $tmp = $settings->check_prefix('workspace') ? $settings->workspace->workdir : undef;
+    local $ENV{TMPDIR} = $tmp if $tmp;
+
     my $db = DBIx::QuickDB->build_db(harness_ui => {driver => qdb_driver($schema), dbd_driver => dbd_driver($schema)});
     $self->{+QDB} = $db;
 
@@ -85,18 +77,27 @@ sub init {
     $port //= 8080;
     $self->{+PORT} = $port;
 
+    $self->{+APP} = $self->start_app();
+
+    $self->SUPER::init();
+}
+
+sub links {
+    my $self = shift;
+
+    return $self->{+LINKS} if defined $self->{+LINKS};
+
+    my $port = $self->{+PORT};
+
     $self->{+LINKS} = "\nYathUI:\n  local: http://127.0.0.1:$port\n";
     if (my $fqdn = hostfqdn()) {
         $self->{+LINKS} .= "  host:  http://$fqdn:$port\n";
     }
+
+    my $dsn = $self->{+QDB}->connect_string('harness_ui');
     $self->{+LINKS} .= "  DSN:   $dsn\n\n";
 
-    STDOUT->autoflush(1);
-    print $self->{+LINKS};
-
-    $self->{+APP} = $self->start_app();
-
-    $self->SUPER::init();
+    return $self->{+LINKS};
 }
 
 sub start_app {
@@ -142,9 +143,6 @@ sub finish {
 
     return $out unless kill(0, $self->{+APP});
 
-    my $dsn = $self->{+QDB}->connect_string('harness_ui');
-    print $self->{+LINKS};
-
     print "Leaving yathui server open, press enter to stop it...\n";
     my $in = <STDIN>;
 
