@@ -7,7 +7,7 @@ use Carp qw/confess/;
 confess "You must first load a Test2::Harness::UI::Schema::NAME module"
     unless $Test2::Harness::UI::Schema::LOADED;
 
-our $VERSION = '0.000036';
+our $VERSION = '0.000037';
 
 __PACKAGE__->inflate_column(
     parameters => {
@@ -86,6 +86,18 @@ sub glance_data {
     return \%data;
 }
 
+sub normalize_to_mode {
+    my $self = shift;
+    my %params = @_;
+
+    my $mode = $params{mode} // $self->run->mode;
+
+    for my $event ($self->events->all) {
+        next if $event->in_mode(mode => $mode, job => $self);
+        $event->delete();
+    }
+}
+
 1;
 
 __END__
